from tradssat.tmpl.var import CharacterVar, FloatVar

cul_vars_BACER = {
    CharacterVar('VAR#', 6, spc=0, info='Identification code or number for the specific cultivar.'),
    CharacterVar('VAR-NAME', 16, header_fill='.', info='Name of cultivar.'),
    CharacterVar('EXP#', 5, miss='.', info='Number of experiments used to generate parameters'),
    CharacterVar('ECO#', 6, info='Ecotype code for this cultivar,points to entry in ECO file'),
    FloatVar('P1V', 5, 0, info='Days,optimum vernalizing temperature,required for vernalization'),
    FloatVar('P1D', 5, 0, info='Photoperiod response (% reduction in rate/10 h drop in pp)'),
    FloatVar('P5', 5, 0, info='Grain filling (excluding lag) phase duration (oC.d)'),
    FloatVar('G1', 5, 0, info='Kernel number per unit canopy weight at anthesis (#/g)'),
    FloatVar('G2', 5, 0, info='Standard kernel size under optimum conditions (mg)'),
    FloatVar('G3', 5, 1, info='Standard,non-stressed mature tiller wt (incl grain) (g dwt)'),
    FloatVar('PHINT', 5, 0, info='Interval between successive leaf tip appearances (oC.d)'),
}

eco_vars_BACER = {
    CharacterVar('ECO#', 6, spc=0, info='Code for the ecotype (code)'),
    FloatVar('GN%MN', 5, 1, info='Minimum grain N (%)'),
    FloatVar('GN%S', 5, 1, info='Standard grain N (%)'),
    FloatVar('HTSTD', 5, 0, info='Standard canopy height (cm)'),
    FloatVar('KCAN', 5, 2, info='PAR extinction coefficient (#)'),
    FloatVar('LA1S', 5, 1, info='Area of standard first leaf (cm2)'),
    FloatVar('LAFR', 5, 2, info='Increase in potential area of leaves,reproductive phase (fr/leaf)'),
    FloatVar('LAFV', 5, 2, info='Increase in potential area of leaves,vegetative phase (fr/leaf)'),
    FloatVar('LARS', 5, 1, info='Area of standard reproductive phase leaf (cm2)'),
    FloatVar('LAVS', 5, 1, info='Area of standard vegetative phase leaf (cm2)'),
    FloatVar('LLIFE', 5, 2, info='Life of leaves during vegetative phase (phyllochrons)'),
    FloatVar('LSPHE', 5, 1, info='Final leaf senescence ends (GrowhStage)'),
    FloatVar('LSPHS', 5, 1, info='Final leaf senescence starts (GrowhStage)'),
    FloatVar('P1', 5, 0, info='Duration of phase end juvenile to terminal spikelet (PVTU)'),
    FloatVar('P2', 5, 0, info='Duration of phase terminal spikelet to end leaf growth (TU)'),
    FloatVar('P2FR1', 5, 2, info='Duration of phase terminal spikelet to jointing (fr P2)'),
    FloatVar('P3', 5, 0, info='Duration of phase end leaf growth to end spike growth (TU)'),
    FloatVar('P4', 5, 0, info='Duration of phase end spike growth to end grain fill lag (TU)'),
    FloatVar('P4FR1', 5, 2, info='Duration of phase end spike growth to anthesis (fr P4)'),
    FloatVar('P4FR2', 5, 2, info='Duration of phase anthesis start to anthesis end (fr P4)'),
    FloatVar('PARU2', 5, 1, info='PAR conversion to dm ratio,after last leaf (g/MJ) (If -99,set to PARUE)'),
    FloatVar('PARUE', 5, 1, info='PAR conversion to dm ratio,before last leaf stage (g/MJ)'),
    FloatVar('PHF3', 5, 2, info='Factor by which PHINTS is multiplied -> PHINT for phase (#)'),
    FloatVar('PHL2', 5, 0, info='Leaf # produced during phyllochron phase (#)'),
    FloatVar('PPFPE', 5, 3, info='Daylength factor,pre emergence (#,0-1)'),
    FloatVar('RDGS', 5, 1, info='Root depth growth rate,early phase (cm/standard d)'),
    FloatVar('RS%S', 5, 0, info='Reserves part of assimilates going to stem (%)'),
    FloatVar('SLAS', 5, 0, info='Specific leaf area,standard first leaf (cm2/g)'),
    FloatVar('TDFAC', 5, 1, info='Tiller death factor (%/st.day when tiller wt 2xstandard wt)'),
    FloatVar('TDPHE', 5, 1, info='Tiller death ending stage (GrowthStage)'),
    FloatVar('TDPHS', 5, 1, info='Tiller death start stage (GrowthStage)'),
    FloatVar('TIFAC', 5, 1, info='Tiller initiation (rate) factor (fr of phyllochron based) (#)'),
    FloatVar('TIL#S', 5, 1, info='Tiller production starts (leaf #)'),
    FloatVar('TIPHE', 5, 1, info='Tillering phase end stage (GrowthStage)'),
    FloatVar('TKFH', 5, 0, info='Temperature at which killed when fully hardened (oC)'),
    FloatVar('VEFF', 5, 1, info='Vernalization effect (Rate reduction when unvernalized (fr)'),
    FloatVar('WFGU', 5, 2, info='Water stress factor,growth,upper (fr)'),
    FloatVar('WFPU', 5, 2, info='Water stress factor,photosynthesis,upper (fr)'),
    FloatVar('AWNS', 5, 2, info='Awn score (0-10;10=very long)')

}
